@@ -1,4 +1,4 @@
-/* WMix 3.0 -- a mixer using the OSS mixer API.
+/* WMix 3.2 -- a mixer using the OSS mixer API.
  * Copyright (C) 2000, 2001
  *	Daniel Richard G. <skunk@mit.edu>,
  *	timecop <timecop@japan.co.jp>
@@ -37,6 +37,7 @@
 #include <X11/cursorfont.h>
 
 #include "include/master.xpm"
+#include "include/master_lcd.xpm"
 #include "include/led-on.xpm"
 #include "include/led-off.xpm"
 
@@ -293,7 +294,22 @@ void new_window(char *name, int width, int height)
     attr.alloc_close_colors = 1;
     attr.closeness = 30000;
     attr.valuemask = (XpmExactColors | XpmAllocCloseColors | XpmCloseness);
-    if ((XpmCreatePixmapFromData(display, DefaultRootWindow(display),
+    if (config.lcd) {
+    	if ((XpmCreatePixmapFromData(display, DefaultRootWindow(display),
+				master_lcd_xpm, &dockapp.pixmap, &dockapp.mask,
+				&attr) != XpmSuccess) ||
+	    (XpmCreatePixmapFromData(display, DefaultRootWindow(display),
+				led_on_xpm, &led_on_pixmap, &led_on_mask,
+				&attr) != XpmSuccess) ||
+	    (XpmCreatePixmapFromData(display, DefaultRootWindow(display),
+				led_off_xpm, &led_off_pixmap, &led_off_mask,
+				&attr) != XpmSuccess)) {
+	fputs("Cannot allocate colors for the dockapp pixmaps!\n", stderr);
+	exit(EXIT_FAILURE);
+    	}
+    }
+    else {
+      if ((XpmCreatePixmapFromData(display, DefaultRootWindow(display),
 				master_xpm, &dockapp.pixmap, &dockapp.mask,
 				&attr) != XpmSuccess) ||
 	    (XpmCreatePixmapFromData(display, DefaultRootWindow(display),
@@ -305,6 +321,7 @@ void new_window(char *name, int width, int height)
 	fputs("Cannot allocate colors for the dockapp pixmaps!\n", stderr);
 	exit(EXIT_FAILURE);
     }
+   }
 
     XShapeCombineMask(display, win, ShapeBounding, 0, 0, dockapp.mask,
 		      ShapeSet);
